@@ -7,8 +7,10 @@ import os
 import pandas as pd
 from graphviz import Digraph
 
-def Carto(Carto_tab_path=os.getcwd()+"\\cartographie.xlsx", Drop=True, view=True):
+def Carto(Carto_tab_path=False, Drop=True, view=True):
 
+    if Carto_tab_path == False:
+        Carto_tab_path = str(os.getcwd()+"\\cartographie.xlsx")
 
     # Importation du fichier excel en dataframe
     df = pd.read_excel(Carto_tab_path, header=[0, 1])
